@@ -856,41 +856,45 @@ Message *AGUIX::wait4mess( int mode )
       }
       break;
     case SelectionNotify:
-      if( (LastEvent.xselection.selection==XA_PRIMARY) &&
-	  (LastEvent.xselection.property!=None) ) {
-	Atom ret_type;
-	int ret_format;
-	unsigned long ret_len,ret_after;
-	unsigned char *ret_prop;
-	XGetWindowProperty(dsp,
-			   LastEvent.xselection.requestor,
-			   LastEvent.xselection.property,
-			   0,
-			   8192,
-			   False,
-			   LastEvent.xselection.target,
-			   &ret_type,
-			   &ret_format,
-			   &ret_len,
-			   &ret_after,
-			   &ret_prop);
-	if(ret_len>0) {
-	  //	  ret_prop[ret_len-1]=0;
-	  if(pastestart!=NULL) pastestart->paste(ret_prop);
-	  XFree(ret_prop);
-	  XDeleteProperty(dsp,LastEvent.xselection.requestor,LastEvent.xselection.property);
-	} else {
-	  if(pastestart!=NULL) pastestart->cancelpaste();
-	  pastestart=NULL;
-	}
-      } else {
-          if ( rerequestCut() ) {
-          } else {
-              if(pastestart!=NULL) pastestart->cancelpaste();
-              pastestart=NULL;
-          }
-      }
-      break;
+        if( (LastEvent.xselection.selection==XA_PRIMARY) &&
+            (LastEvent.xselection.property!=None) ) {
+            Atom ret_type;
+            int ret_format;
+            unsigned long ret_len,ret_after;
+            unsigned char *ret_prop;
+            if ( XGetWindowProperty(dsp,
+                                    LastEvent.xselection.requestor,
+                                    LastEvent.xselection.property,
+                                    0,
+                                    8192,
+                                    False,
+                                    LastEvent.xselection.target,
+                                    &ret_type,
+                                    &ret_format,
+                                    &ret_len,
+                                    &ret_after,
+                                    &ret_prop) == Success ) {
+                if (ret_len > 0) {
+                    //	  ret_prop[ret_len-1]=0;
+                    if(pastestart!=NULL) pastestart->paste(ret_prop);
+                    XDeleteProperty(dsp,LastEvent.xselection.requestor,LastEvent.xselection.property);
+                } else {
+                    if(pastestart!=NULL) pastestart->cancelpaste();
+                    pastestart=NULL;
+                }
+                XFree(ret_prop);
+            } else {
+                if(pastestart!=NULL) pastestart->cancelpaste();
+                pastestart=NULL;
+            }
+        } else {
+            if ( rerequestCut() ) {
+            } else {
+                if(pastestart!=NULL) pastestart->cancelpaste();
+                pastestart=NULL;
+            }
+        }
+        break;
     case SelectionRequest:
       XEvent ev;
       ev.type=SelectionNotify;
@@ -1476,29 +1480,43 @@ void AGUIX::createGroupWin()
   XSetWMProtocols(dsp,groupwin,getCloseAtom(),1);
   XSizeHints *SizeHints;
   XWMHints *WMHints;
+
   SizeHints=XAllocSizeHints();
+
+  if ( SizeHints ) {
+      SizeHints->flags=PSize;
+      SizeHints->width=10;
+      SizeHints->height=10;
+
+      XSetWMNormalHints(dsp,groupwin,SizeHints);
+
+      XFree(SizeHints);
+  }
+
   WMHints=XAllocWMHints();
-  SizeHints->flags=PSize;
-  SizeHints->width=10;
-  SizeHints->height=10;
-  WMHints->input=True;
 
-  WMHints->window_group=groupwin;
+  if ( WMHints ) {
+      WMHints->input=True;
+      WMHints->window_group=groupwin;
+      WMHints->flags=InputHint|WindowGroupHint;
 
-  WMHints->flags=InputHint|WindowGroupHint;
-  XStringListToTextProperty(&tstr,1,&windowname);
-  XStringListToTextProperty(&tstr,1,&iconname);
-  XSetWMName(dsp,groupwin,&windowname);
-  XSetWMIconName(dsp,groupwin,&iconname);
-  XSetWMHints(dsp,groupwin,WMHints);
-  XSetWMNormalHints(dsp,groupwin,SizeHints);
+      XSetWMHints(dsp,groupwin,WMHints);
+
+      XFree(WMHints);
+  }
+
+  if ( XStringListToTextProperty(&tstr,1,&windowname) != 0 ) {
+      XSetWMName(dsp,groupwin,&windowname);
+      XFree( windowname.value );
+  }
+
+  if ( XStringListToTextProperty(&tstr,1,&iconname) != 0 ) {
+      XSetWMIconName(dsp,groupwin,&iconname);
+      XFree( iconname.value );
+  }
   XStoreName(dsp,groupwin,tstr);
-  XFree(SizeHints);
-  XFree(WMHints);
   _freesafe(tstr);
   XSetCommand(dsp,groupwin,getargv(),getargc());
-  XFree( windowname.value );
-  XFree( iconname.value );
 }
 
 void AGUIX::destroyGroupWin()
@@ -2302,13 +2320,17 @@ int AGUIX::openIM()
        are not supported and dead keys will be loockuped to their normal character
     */
     supported_styles = XIMPreeditNothing | XIMStatusNothing;
-    XGetIMValues( inputmethod, XNQueryInputStyle, &im_supported_styles, (void*)NULL );
+
     im_style = 0;
-    for ( i = 0; i < im_supported_styles->count_styles; i++ ) {
-      style = im_supported_styles->supported_styles[i];
-      if ( ( style & supported_styles ) == style ) {
-	im_style = ChooseBetterStyle( style, im_style );
-      }
+
+    if ( XGetIMValues( inputmethod, XNQueryInputStyle, &im_supported_styles, (void*)NULL ) == NULL ) {
+        for ( i = 0; i < im_supported_styles->count_styles; i++ ) {
+            style = im_supported_styles->supported_styles[i];
+            if ( ( style & supported_styles ) == style ) {
+                im_style = ChooseBetterStyle( style, im_style );
+            }
+        }
+        XFree( im_supported_styles );
     }
     
     if ( im_style == 0 ) {
@@ -2322,7 +2344,6 @@ int AGUIX::openIM()
             (*it1)->createXIC();
         }
     }
-    XFree( im_supported_styles );
   }
   return ( ( ( inputmethod != NULL ) && ( im_style != 0 ) ) ? 0 : 1 );
 }
