@@ -428,7 +428,10 @@ private:
     int m_3d_bright;
     int m_3d_dark;
 
-    struct {
+    struct bubble_help_data {
+        bubble_help_data() : help_candidate( NULL ),
+                             enter_time{ 0, 0 }
+        {}
         std::shared_ptr< BubbleWindow > bubble_help_window;
         GUIElement *help_candidate;
         struct timeval enter_time;
