@@ -141,19 +141,24 @@ void AWindow::setMaxSize(int mwidth,int mheight)
   XSizeHints *SizeHints;
   Display *dsp=_aguix->getDisplay();
   SizeHints=XAllocSizeHints();
-  if(minw>=0) {
-    SizeHints->flags=PMaxSize|PMinSize;
-    SizeHints->min_width=minw;
-    SizeHints->min_height=minh;
-  } else {
-    SizeHints->flags=PMaxSize;
+
+  if ( SizeHints ) {
+      if(minw>=0) {
+          SizeHints->flags=PMaxSize|PMinSize;
+          SizeHints->min_width=minw;
+          SizeHints->min_height=minh;
+      } else {
+          SizeHints->flags=PMaxSize;
+      }
+      SizeHints->max_width=mwidth;
+      SizeHints->max_height=mheight;
+
+      XSetWMNormalHints(dsp,win,SizeHints);
+      XFree(SizeHints);
   }
-  SizeHints->max_width=mwidth;
-  SizeHints->max_height=mheight;
+
   maxw=mwidth;
   maxh=mheight;
-  XSetWMNormalHints(dsp,win,SizeHints);
-  XFree(SizeHints);
 }
 
 void AWindow::setMinSize(int mwidth,int mheight)
@@ -161,19 +166,24 @@ void AWindow::setMinSize(int mwidth,int mheight)
   XSizeHints *SizeHints;
   Display *dsp=_aguix->getDisplay();
   SizeHints=XAllocSizeHints();
-  if(maxw>=0) {
-    SizeHints->flags=PMaxSize|PMinSize;
-    SizeHints->max_width=maxw;
-    SizeHints->max_height=maxh;
-  } else {
-    SizeHints->flags=PMinSize;
+
+  if ( SizeHints ) {
+      if(maxw>=0) {
+          SizeHints->flags=PMaxSize|PMinSize;
+          SizeHints->max_width=maxw;
+          SizeHints->max_height=maxh;
+      } else {
+          SizeHints->flags=PMinSize;
+      }
+      SizeHints->min_width=mwidth;
+      SizeHints->min_height=mheight;
+
+      XSetWMNormalHints(dsp,win,SizeHints);
+      XFree(SizeHints);
   }
-  SizeHints->min_width=mwidth;
-  SizeHints->min_height=mheight;
+
   minw=mwidth;
   minh=mheight;
-  XSetWMNormalHints(dsp,win,SizeHints);
-  XFree(SizeHints);
 }
 
 void AWindow::show()
@@ -1007,19 +1017,23 @@ void AWindow::doCreateStuff()
 
   // size of the window
   SizeHints = XAllocSizeHints();
-  SizeHints->flags = PSize;
-  SizeHints->width = _w;
-  SizeHints->height = _h;
-  XSetWMNormalHints( dsp, win, SizeHints );
-  XFree( SizeHints );
+  if ( SizeHints ) {
+      SizeHints->flags = PSize;
+      SizeHints->width = _w;
+      SizeHints->height = _h;
+      XSetWMNormalHints( dsp, win, SizeHints );
+      XFree( SizeHints );
+  }
 
   // window grouping for window managers
   WMHints = XAllocWMHints();
-  WMHints->input = True;
-  WMHints->window_group = _aguix->getGroupWin();
-  WMHints->flags = InputHint | WindowGroupHint;
-  XSetWMHints( dsp, win, WMHints );
-  XFree( WMHints );
+  if ( WMHints ) {
+      WMHints->input = True;
+      WMHints->window_group = _aguix->getGroupWin();
+      WMHints->flags = InputHint | WindowGroupHint;
+      XSetWMHints( dsp, win, WMHints );
+      XFree( WMHints );
+  }
   
   // command so the window manager can restart worker
   XSetCommand( dsp, win, _aguix->getargv(), _aguix->getargc() );
@@ -1163,7 +1177,7 @@ int AWindow::setWMTitle()
 {
   Display *dsp;
   XClassHint classhint;
-  XTextProperty windowname, ticonname, utf8name;
+  XTextProperty windowname;
   char *tstr;
   
   dsp = _aguix->getDisplay();
@@ -1176,24 +1190,30 @@ int AWindow::setWMTitle()
   _freesafe( classhint.res_name );
   
   tstr = dupstring( _title.c_str() );
-  XStringListToTextProperty( &tstr, 1, &windowname );
-  XStringListToTextProperty( &tstr, 1, &ticonname );
 
-  XSetWMName( dsp, win, &windowname );
-  XSetWMIconName( dsp, win, &ticonname );
+  if ( XStringListToTextProperty( &tstr, 1, &windowname ) != 0 ) {
+      XTextProperty ticonname;
+      if ( XStringListToTextProperty( &tstr, 1, &ticonname ) != 0 ) {
+          XSetWMName( dsp, win, &windowname );
+          XSetWMIconName( dsp, win, &ticonname );
+          XFree( ticonname.value );
+      }
+      XFree( windowname.value );
+  }
 
 #if defined( X_HAVE_UTF8_STRING ) && !defined( DISABLE_UTF8_SUPPORT )
   if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
-    XmbTextListToTextProperty( dsp, &tstr, 1, XUTF8StringStyle, &utf8name );
-    XSetTextProperty( dsp, win, &utf8name, _aguix->getAtom( AGUIX::NET_WM_NAME_ATOM ) );
-    XSetTextProperty( dsp, win, &utf8name, _aguix->getAtom( AGUIX::NET_WM_ICON_NAME_ATOM ) );
-    XFree( utf8name.value );
+      XTextProperty utf8name;
+
+      if ( XmbTextListToTextProperty( dsp, &tstr, 1, XUTF8StringStyle, &utf8name ) == Success ) {
+          XSetTextProperty( dsp, win, &utf8name, _aguix->getAtom( AGUIX::NET_WM_NAME_ATOM ) );
+          XSetTextProperty( dsp, win, &utf8name, _aguix->getAtom( AGUIX::NET_WM_ICON_NAME_ATOM ) );
+          XFree( utf8name.value );
+      }
   }
 #endif
 
   _freesafe( tstr );
-  XFree( windowname.value );
-  XFree( ticonname.value );
   
   XStoreName( dsp, win, _title.c_str() );
   
