@@ -1153,9 +1153,9 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
                                                                                            linkdest );
                                                 fulloldlink = NWC::Path::normalize( fulloldlink );
 
-                                                char *newrellinkdest = Datei::getRelativePath( fulloldlink.c_str(),
-                                                                                               NWC::Path::dirname( newfullname ).c_str(),
-                                                                                               true );
+                                                char *newrellinkdest = Datei::getRelativePathExt( fulloldlink.c_str(),
+                                                                                                  NWC::Path::dirname( newfullname ).c_str(),
+                                                                                                  true );
 
                                                 if ( newrellinkdest && strlen( newrellinkdest ) > 0 ) {
                                                     free( linkdest );
