@@ -132,7 +132,8 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
           if ( wpu->parse( _tcustom_files.c_str(),
                            res_str,
                            a_max( EXE_STRING_LEN - 1024, 256 ),
-                           true ) == WPUContext::PARSE_SUCCESS ) {
+                           true,
+                           WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
               char **argvlist;
               char *unquoted_str;
               int n, i;
