@@ -114,7 +114,7 @@ int ChangeListerSetOp::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(19))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(19));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -127,8 +127,8 @@ int ChangeListerSetOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 348 ), 1 ), 0, 0, cfix );
-  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 348 ) ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(326));
   rcyb->addOption(catalog.getLocale(327));
   rcyb->addOption(catalog.getLocale(324));
@@ -159,15 +159,11 @@ int ChangeListerSetOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
@@ -367,7 +363,9 @@ int FilterSelectOp::run( WPUContext *wpu, ActionMessage *msg )
 
             lm1->getSelFiles( extfilelist, ListerMode::LM_GETFILES_ONLYACTIVE );
             for ( auto &ss1 : extfilelist ) {
-                entry_basename = ss1.entry()->name;
+                if ( ss1.entry() ) {
+                    entry_basename = ss1.entry()->name;
+                }
             }
 
             if ( requestfilter( entry_basename ) == true ) {
@@ -403,7 +401,7 @@ int FilterSelectOp::configure()
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(21))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(21));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
   
@@ -416,7 +414,7 @@ int FilterSelectOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ), 1 ), 0, 0, cfix );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ) ), 0, 0, cfix );
   sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
 						    filter.c_str(),
 						    0 ), 1, 0, cincw );
@@ -429,15 +427,11 @@ int FilterSelectOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, cfix );
 
   win->setDoTabCycling( true );
@@ -499,7 +493,7 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
 
-  win = new AWindow( aguix, 10, 10, 10, 10, 0,
+  win = new AWindow( aguix, 10, 10, 10, 10,
                      catalog.getLocale( ( m_mode == 1 ) ? 269 : 268 ),
                      AWindow::AWINDOW_DIALOG );
   win->create();
@@ -509,9 +503,9 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
   ac1->setMaxSpace( 5 );
 
   ac1->add( new Text( aguix, 0, 0,
-                      catalog.getLocale( ( m_mode == 1 ) ? 271 : 270 ),
-                      1 ), 0, 0, cincwnr );
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 272 ), 1 ), 0, 1, cincwnr );
+                      catalog.getLocale( ( m_mode == 1 ) ? 271 : 270 )
+                      ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 272 ) ), 0, 1, cincwnr );
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 2 ), 0, 2 );
   ac1_1->setMinSpace( 0 );
@@ -578,24 +572,20 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, cfix );
   win->contMaximize( true );
 
-  w = Worker::getKVPStore().getIntValue( "filterselect-width",
-                                         win->getWidth(),
-                                         10000 );
-  h = Worker::getKVPStore().getIntValue( "filterselect-height",
-                                         win->getHeight(),
-                                         10000 );
+  w = Worker::getPersKVPStore().getIntValue( "filterselect-width",
+                                             win->getWidth(),
+                                             10000 );
+  h = Worker::getPersKVPStore().getIntValue( "filterselect-height",
+                                             win->getHeight(),
+                                             10000 );
   //w = ( lastw > 0 ) ? lastw : win->getWidth();
   //h = ( lasth > 0 ) ? lasth : win->getHeight();
 
@@ -668,10 +658,10 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
       addHistoryItem( current_filter );
   }
 
-  Worker::getKVPStore().setIntValue( "filterselect-width",
-                                     win->getWidth() );
-  Worker::getKVPStore().setIntValue( "filterselect-height",
-                                     win->getHeight() );
+  Worker::getPersKVPStore().setIntValue( "filterselect-width",
+                                         win->getWidth() );
+  Worker::getPersKVPStore().setIntValue( "filterselect-height",
+                                         win->getHeight() );
 
   lastw = win->getWidth();
   lasth = win->getHeight();
@@ -767,7 +757,9 @@ int FilterUnSelectOp::run( WPUContext *wpu, ActionMessage *msg )
 
             lm1->getSelFiles( extfilelist, ListerMode::LM_GETFILES_ONLYACTIVE );
             for ( auto &ss1 : extfilelist ) {
-                entry_basename = ss1.entry()->name;
+                if ( ss1.entry() ) {
+                    entry_basename = ss1.entry()->name;
+                }
             }
 
             if ( requestfilter( entry_basename ) == true ) {
@@ -803,7 +795,7 @@ int FilterUnSelectOp::configure()
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(22))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(22));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
   
@@ -816,7 +808,7 @@ int FilterUnSelectOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ), 1 ), 0, 0, cfix );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 349 ) ), 0, 0, cfix );
 
   sg = (StringGadget*)ac1_1->add( new StringGadget( aguix, 0, 0, 100,
 						    filter.c_str(),
@@ -830,15 +822,11 @@ int FilterUnSelectOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cancelb = (Button*)ac1_2->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, cfix );
 
   win->setDoTabCycling( true );
@@ -1006,7 +994,7 @@ int QuitOp::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(24))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(24));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -1019,8 +1007,8 @@ int QuitOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 350 ), 1 ), 0, 0, cfix );
-  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 350 ) ), 0, 0, cfix );
+  rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   rcyb->addOption(catalog.getLocale(351));
   rcyb->addOption(catalog.getLocale(352));
   rcyb->resize(rcyb->getMaxSize(),rcyb->getHeight());
@@ -1043,15 +1031,11 @@ int QuitOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
