@@ -1,6 +1,6 @@
 /* wconfig_clock.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011-2012 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -56,10 +56,10 @@ int ClockPanel::create()
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( 5 );
   
-  ac1_1->add( new Text( _aguix, 0, 0, catalog.getLocale( 369 ), 1 ),
+  ac1_1->add( new Text( _aguix, 0, 0, catalog.getLocale( 369 ) ),
               0, 0, AContainer::CO_FIX );
   
-  cyb = (CycleButton*)ac1_1->add( new CycleButton( _aguix, 0, 0, 100, 1, 0, 0 ),
+  cyb = (CycleButton*)ac1_1->add( new CycleButton( _aguix, 0, 0, 100, 0 ),
                                 1, 0, AContainer::CO_INCW );
   cyb->connect( this );
   cyb->addOption( catalog.getLocale( 370 ) );
@@ -83,7 +83,7 @@ int ClockPanel::create()
   }
   ac1_1->readLimits();
   
-  cuwin = new AWindow( _aguix, 0, 0, 10, 10, 0, "" );
+  cuwin = new AWindow( _aguix, 0, 0, 10, 10, "" );
   ac1->add( cuwin, 0, 2, AContainer::CO_INCW );
   cuwin->create();
 
@@ -92,7 +92,7 @@ int ClockPanel::create()
   ac1_cuwin->setMinSpace( 5 );
   ac1_cuwin->setMaxSpace( 5 );
 
-  ac1_cuwin->add( new Text( _aguix, 0, 0, catalog.getLocale(129), 1 ), 0, 0, AContainer::CO_FIX );
+  ac1_cuwin->add( new Text( _aguix, 0, 0, catalog.getLocale(129) ), 0, 0, AContainer::CO_FIX );
 
   tstr = (char*)_allocsafe( A_BYTESFORNUMBER( int ) );
   sprintf( tstr, "%d", _baseconfig.getClockbarUpdatetime() );
@@ -102,7 +102,7 @@ int ClockPanel::create()
   cuwin->contMaximize( true );
   cuwin->show();
   
-  ccwin = new AWindow( _aguix, 0, 0, 10, 10, 0, "" );
+  ccwin = new AWindow( _aguix, 0, 0, 10, 10, "" );
   ac1->add( ccwin, 0, 3, AContainer::CO_INCW );
   ccwin->create();
 
@@ -111,7 +111,7 @@ int ClockPanel::create()
   ac1_ccwin->setMinSpace( 5 );
   ac1_ccwin->setMaxSpace( 5 );
 
-  ac1_ccwin->add( new Text( _aguix, 0, 0, catalog.getLocale(374), 1 ), 0, 0, AContainer::CO_FIX );
+  ac1_ccwin->add( new Text( _aguix, 0, 0, catalog.getLocale(374) ), 0, 0, AContainer::CO_FIX );
   ccsg = (StringGadget*)ac1_ccwin->add( new StringGadget( _aguix, 0, 0, 200, _baseconfig.getClockbarCommand(), 0 ), 1, 0, AContainer::CO_INCW );
   ccsg->connect( this );
 
@@ -122,7 +122,7 @@ int ClockPanel::create()
 
   m_hint_cb = (ChooseButton*)ac1->add( new ChooseButton( _aguix, 0, 0,
                                                          _baseconfig.getClockbarHints(),
-                                                         catalog.getLocale( 987 ), LABEL_RIGHT, 1, 0 ),
+                                                         catalog.getLocale( 987 ), LABEL_RIGHT, 0 ),
                                        0, 4, AContainer::CO_INCWNR );
 
   // now check which extra fields are visible
